@@ -41,8 +41,6 @@
 
 #define KGLOBALACCEL_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KGLOBALACCEL_NO_DEPRECATED) && !defined(KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KGLOBALACCEL_DEPRECATED
-#  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
